DistMultInteraction
===================

.. currentmodule:: pykeen.nn.modules

.. autoclass:: DistMultInteraction
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~DistMultInteraction.func

   .. rubric:: Methods Documentation

   .. automethod:: func
